@@ -191,7 +191,7 @@ def plot_trajectories(ax, path, size=10, color='r'):
     """
     Plot plot_trajectories
     """
-    ax.scatter([x for (x, y, z) in path], [y for (x, y, z) in path], [z for (x, y, z) in path], s=s, c=c)
+    ax.scatter([x for (x, y, z) in path], [y for (x, y, z) in path], [z for (x, y, z) in path], s=size, c=color)
 
 def plot_animation(
     robot, 
